@@ -856,6 +856,7 @@ S26-documentation/why-trailing.t
 S26-documentation/why-leading.t
 S28-named-variables/cwd.t
 S28-named-variables/slangs.t    # moar
+S29-any/are.t
 S29-any/cmp.t
 S29-any/isa.t
 S29-context/die.t
@@ -1035,6 +1036,7 @@ S32-str/trim.t
 S32-str/uc.t
 S32-str/unpack.t
 S32-str/utf8-c8.t       # moar
+S32-str/val.t
 S32-str/words.t
 S32-temporal/calendar.t
 S32-temporal/Date.t
